@@ -15,7 +15,7 @@
 #  limitations under the License.
 
 import sys
-import progressbar
+import calculate.contrib.progressbar as progressbar
 
 class DoubleMarkerBar(progressbar.Bar):
     """
