@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright 2015 Calculate Ltd. http://www.calculate-linux.org
+# Copyright 2015-2016 Mir Calculate. http://www.calculate-linux.org
 #
 #  Licensed under the Apache License, Version 2.0 (the "License");
 #  you may not use this file except in compliance with the License.
@@ -19,6 +19,7 @@ class Dracut(object):
     IsoScanPath = "/run/initramfs/isoscan"
     IsoLive = "/run/initramfs/live"
     SquashLive = "/run/initramfs/squashfs"
-    Workspace = '/run/initramfs/workspace'
+    Workspace = "/run/initramfs/workspace"
+    Initramfs = "/run/initramfs"
 
     IsoScanCmdParam = "iso-scan/filename"
