@@ -14,9 +14,12 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 import sys
-from calculate.lib.utils.files import grepFile
-from calculate.lib.utils.tools import cached
+from calculate.lib.utils.files import grepFile, getRunCommands
+from calculate.lib.utils.tools import cached, traverse
 from os import path
+import os
+from collections import defaultdict
+from fnmatch import fnmatch, filter as fnfilter
 
 _ = lambda x: x
 from calculate.lib.cl_lang import setLocalTranslate
@@ -105,3 +108,45 @@ class SystemType(object):
     @classmethod
     def detect(cls):
         return cls.detect_container() or cls.detect_vm()
+
+class FUser(object):
+    def __init__(self, ffilter=None):
+        self.ffilter = ffilter
+        self.ref = defaultdict(list)
+        self.refresh()
+
+    def get_mnt(self, pid):
+        try:
+            return os.readlink("/proc/%s/ns/mnt" %pid).strip()
+        except Exception:
+            return ""
+
+    def get_main_mnt(self):
+        return self.get_mnt("1")
+
+    def refresh(self):
+        self.ref=defaultdict(list)
+        main_mnt = self.get_main_mnt()
+        for p in os.listdir("/proc/"):
+            if not p.isdigit(): continue
+            if self.get_mnt(p) != main_mnt: continue
+            d = "/proc/%s/fd/" % p
+            try:
+               for fd in os.listdir(d):
+                 f = os.readlink(d+fd)
+                 self.ref[f].append(p)
+            except OSError:
+                pass
+
+    def search(self, item):
+        keys = fnfilter(self.ref.keys(), item)
+        return traverse(self.ref[k] for k in keys)
+
+    def __contains__(self, item):
+        return item in self.ref
+
+    def __getitem__(self, item):
+        return self.ref[item]
+
+emerge_running = lambda: any(fnmatch(x, "*python-exec/*/emerge*")
+                             for x in getRunCommands(True))
